@@ -3,6 +3,7 @@
 """
 # pylint: disable = global-statement
 
+from __future__ import annotations # See https://peps.python.org/pep-0563/
 
 from contextlib import contextmanager
 import math
@@ -14,8 +15,8 @@ from typing_validation import validate
 
 from multiformats import multicodec, multibase, multihash, CID
 
-from .encoding import encode, EncodableType
-from .utils import _canonical_order_dict
+from .ipld import IPLDKind
+from .encoding import encode, _canonical_order_dict
 
 _min_int = -18446744073709551616
 _max_int = 18446744073709551615
@@ -250,14 +251,12 @@ def set_options(*,
     _options = _new_options
 
 
-def rand_data(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[EncodableType]:
+def rand_data(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[IPLDKind]:
     r"""
         Generates a stream of random data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
         :param max_nesting: the maximum nesting level for containers; if :obj:`None`, value from :func:`get_options` is used
-        :type max_nesting: :obj:`int` or :obj:`None`, *optional*
 
         Maximum nesting level for containers:
 
@@ -265,13 +264,12 @@ def rand_data(n: Optional[int] = None, *, max_nesting: Optional[int] = None) ->
         - integer values >= 0 mean that containers will be generated, with items generated by ``random_data(max_nesting=max_nesting-1)``
         - no other values are valid
 
-        :rtype: :obj:`~typing.Iterator`\ [:obj:`~dag_cbor.encoding.EncodableType`]
     """
     validate(n, Optional[int])
     validate(max_nesting, Optional[int])
     return _rand_data(n, max_nesting=max_nesting)
 
-def _rand_data(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[EncodableType]:
+def _rand_data(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[IPLDKind]:
     if n is not None and n < 0:
         raise ValueError()
     if max_nesting is None:
@@ -309,11 +307,8 @@ def rand_list(n: Optional[int] = None, *, length: Optional[int] = None, max_nest
         Generates a stream of random :obj:`list` data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
         :param length: size for the lists; if :obj:`None`, a random value is sampled according to the :func:`options`
-        :type length: :obj:`int` or :obj:`None`, *optional*
         :param max_nesting: the maximum nesting level for containers; if :obj:`None`, value from :func:`get_options` is used
-        :type max_nesting: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     validate(length, Optional[int])
@@ -342,11 +337,8 @@ def rand_dict(n: Optional[int] = None, *, length: Optional[int] = None, max_nest
         Generates a stream of random :obj:`dict` data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
         :param length: size for the dicts; if :obj:`None`, a random value is sampled according to the :func:`options`
-        :type length: :obj:`int` or :obj:`None`, *optional*
         :param max_nesting: the maximum nesting level for containers; if :obj:`None`, value from :func:`get_options` is used
-        :type max_nesting: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     validate(length, Optional[int])
@@ -409,7 +401,6 @@ def rand_int(n: Optional[int] = None) -> Iterator[int]:
         Generates a stream of random :obj:`int` data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     return _rand_int(n)
@@ -429,9 +420,7 @@ def rand_bytes(n: Optional[int] = None, *, length: Optional[int] = None) -> Iter
         Generates a stream of random :obj:`bytes` data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
         :param length: length of the bytestrings; if :obj:`None`, a random value is sampled according to the :func:`options`
-        :type length: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     validate(length, Optional[int])
@@ -455,9 +444,7 @@ def rand_str(n: Optional[int] = None, *, length: Optional[int] = None) -> Iterat
         Generates a stream of random :obj:`str` data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
         :param length: length of the strings; if :obj:`None`, a random value is sampled according to the :func:`options`
-        :type length: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     validate(length, Optional[int])
@@ -489,7 +476,6 @@ def rand_bool(n: Optional[int] = None) -> Iterator[bool]:
         Generates a stream of random :obj:`bool` data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     return _rand_bool(n)
@@ -508,7 +494,6 @@ def rand_bool_none(n: Optional[int] = None) -> Iterator[Optional[bool]]:
         Generates a stream of random :obj:`bool` or :obj:`None` data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     return _rand_bool_none(n)
@@ -527,7 +512,6 @@ def rand_float(n: Optional[int] = None) -> Iterator[float]:
         Generates a stream of random :obj:`float` data.
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     return _rand_float(n)
@@ -564,7 +548,7 @@ _cid_version = 1
 _cid_multicodec = multicodec.get("dag-cbor")
 _cid_multihash = multihash.get("sha3-512")
 
-def rand_data_cid(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[Tuple[EncodableType, CID]]:
+def rand_data_cid(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[Tuple[IPLDKind, CID]]:
     r"""
         Generates a stream of random DAG-CBOR data and associated CIDs:
 
@@ -574,11 +558,8 @@ def rand_data_cid(n: Optional[int] = None, *, max_nesting: Optional[int] = None)
         - multihash 'sha3-512', with full 512-bit digest
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
         :param max_nesting: the maximum nesting level for containers; if :obj:`None`, value from :func:`get_options` is used
-        :type max_nesting: :obj:`int` or :obj:`None`, *optional*
 
-        :rtype: :obj:`~typing.Iterator`\ [:obj:`~typing.Tuple`\ [:obj:`~dag_cbor.encoding.EncodableType`, :obj:`~multiformats.cid.CID`]]
     """
     validate(n, Optional[int])
     return _rand_data_cid(n, max_nesting=max_nesting)
@@ -593,9 +574,7 @@ def rand_cid(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> I
         - multihash 'sha3-512', with full 512-bit digest
 
         :param n: the number of samples to be yielded; if :obj:`None`, an infinite stream is yielded
-        :type n: :obj:`int` or :obj:`None`, *optional*
         :param max_nesting: the maximum nesting level for containers; if :obj:`None`, value from :func:`get_options` is used
-        :type max_nesting: :obj:`int` or :obj:`None`, *optional*
     """
     validate(n, Optional[int])
     return _rand_cid(n, max_nesting=max_nesting)
@@ -603,7 +582,7 @@ def rand_cid(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> I
 def _rand_cid(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[CID]:
     return (cid for _, cid in _rand_data_cid(n, max_nesting=max_nesting))
 
-def _rand_data_cid(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[Tuple[EncodableType, CID]]:
+def _rand_data_cid(n: Optional[int] = None, *, max_nesting: Optional[int] = None) -> Iterator[Tuple[IPLDKind, CID]]:
     if n is not None and n < 0:
         raise ValueError()
     if max_nesting is None:
